@@ -1,5 +1,5 @@
 package App::Colorist::Colorizer;
-$App::Colorist::Colorizer::VERSION = '0.141760';
+$App::Colorist::Colorizer::VERSION = '0.142540';
 use Moose;
 
 use Carp;
@@ -242,7 +242,7 @@ sub load_ruleset_file {
             ruleset;
         use App::Colorist::Ruleset;
         $rules = do "$ruleset_file"
-            or croak(qq[Failed to read rule set "$ruleset_file": $@]);
+            or Carp::croak(qq[Failed to read rule set "$ruleset_file": $@]);
         push @$rules, qr{.*}, [ 'DEFAULT' ];
     }
 
@@ -502,8 +502,8 @@ sub colorize {
                 || ($a->[1] eq 'Y' and $b->[1] eq 'Y' ? $b->[2] <=> $a->[2] # X? name index (asc)
                     :                                    $a->[2] <=> $b->[2]) # Y? XY? YX? index (desc)
             } (
-                (map { [ $-[$_], 'X', $_ ] } 0 .. $#- ),
-                (map { [ $+[$_], 'Y', $_ ] } 0 .. $#+ ),
+                (map { [ ($-[$_] // 0), 'X', $_ ] } 0 .. $#- ),
+                (map { [ ($+[$_] // 0), 'Y', $_ ] } 0 .. $#+ ),
             );
             @pos = ([ 0, 'X', undef ], @pos, [ length, 'Y', undef ]);
             #warn YAML::Dump(\@pos);
@@ -562,7 +562,7 @@ App::Colorist::Colorizer - the brain behind App::Colorist
 
 =head1 VERSION
 
-version 0.141760
+version 0.142540
 
 =head1 SYNOPSIS
 
